@@ -6,6 +6,9 @@
     if (!inherits(formula, "formula"))
         stop("method is only for formula objects")
     m <- match.call(expand = FALSE)
+    ## Catch xtest and ytest in arguments.
+    if (any(c("xtest", "ytest") %in% names(m)))
+        stop("xtest/ytest not supported through the formula interface")
     names(m)[2] <- "formula"
     if (is.matrix(eval(m$data, parent.frame())))
         m$data <- as.data.frame(data)
