@@ -1,6 +1,6 @@
 .onAttach <- function(libname, pkgname) {
     RFver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
                       fields="Version")
-    cat(paste(pkgname, RFver, "\n"))
-    cat("Type rfNews() to see new features/changes/bug fixes.\n")
+    message(paste(pkgname, RFver))
+    message("Type rfNews() to see new features/changes/bug fixes.")
 }
